@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -24,30 +24,26 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/url.h>
 
 
-// Entry dialog constructor
+// Entry dialog constructor.
 // $url: The base URL of the page.
 // $question: The question to be asked.
 // $info_top : Information.
 // $info_bottom: Information.
 // $post: causes the result to be sent via the POST method rather than the default GET method.
-Dialog_List::Dialog_List (string url, string question, string info_top, string info_bottom, bool post)
+Dialog_List::Dialog_List (std::string url, std::string question, std::string info_top, std::string info_bottom, bool post)
 {
-  Assets_View * view = new Assets_View ();
   base_url = url;
-  view->set_variable ("question", question);
+  assets_view.set_variable ("question", question);
   if (info_top == "") info_top = translate("Here are the various options:");
-  view->set_variable ("info_top", info_top);
+  assets_view.set_variable ("info_top", info_top);
   if (info_bottom == "") info_bottom = translate("Please pick one.");
-  view->set_variable ("info_bottom", info_bottom);
+  assets_view.set_variable ("info_bottom", info_bottom);
   post_result = post;
-  assets_view = view;
 }
 
 
 Dialog_List::~Dialog_List ()
 {
-  Assets_View * view = (Assets_View *) assets_view;
-  delete view;
 }
 
 
@@ -55,36 +51,35 @@ Dialog_List::~Dialog_List ()
 // If any $query is passed, if Cancel is clicked in this dialog, it should go go back
 // to the original caller page  with the $query added.
 // Same for when a selection is made: It adds the $query to the page where to go.
-void Dialog_List::add_query (string parameter, string value)
+void Dialog_List::add_query (std::string parameter, std::string value)
 {
   base_url = filter_url_build_http_query (base_url, parameter, value);
 }
 
 
-void Dialog_List::add_row (string text, string parameter, string value)
+void Dialog_List::add_row (std::string text, std::string parameter, std::string value)
 {
   if (!list_block.empty ()) list_block.append ("\n");
   list_block.append ("<li>");
   if (post_result) {
     list_block.append ("\n");
-    list_block.append ("<form action=\"" + base_url + "\" method=\"post\">\n");
-    list_block.append ("<a href=\"javascript:;\" onclick=\"parentNode.submit();\">" + text + "</a>\n");
-    list_block.append ("<input type=\"hidden\" name=\"add\" value=\"" + value + "\" />\n");
+    list_block.append (R"(<form action=")" + base_url + R"(" method="post">)" + "\n");
+    list_block.append (R"(<a href="javascript:;" onclick="parentNode.submit();">)" + text + "</a>\n");
+    list_block.append (R"(<input type="hidden" name="add" value=")" + value + R"(" />)" + "\n");
     list_block.append ("</form>\n");
   } else {
-    string href = filter_url_build_http_query (base_url, parameter, value);
-    list_block.append ("<a href=\"" + href + "\">" + text + "</a>");
+    std::string href = filter_url_build_http_query (base_url, parameter, value);
+    list_block.append (R"(<a href=")" + href + R"(">)" + text + "</a>");
   }
   list_block.append ("</li>");
 }
 
 
-string Dialog_List::run ()
+std::string Dialog_List::run ()
 {
-  Assets_View * view = (Assets_View *) assets_view;
-  view->set_variable ("base_url", base_url);
-  view->set_variable ("list_block", list_block);
-  string page = view->render ("dialog", "list");
-  page += Assets_Page::footer ();
+  assets_view.set_variable ("base_url", base_url);
+  assets_view.set_variable ("list_block", list_block);
+  std::string page = assets_view.render ("dialog", "list");
+  page += assets_page::footer ();
   return page;
 }
