@@ -40,6 +40,7 @@
 
 #pragma clang diagnostic ignored "-Wsign-conversion"
 
+
 namespace dtl {
     
     /**
@@ -164,7 +165,7 @@ namespace dtl {
             return trivial;
         }
         
-        void enableTrivial () const {
+        void enableTrivial () {
             this->trivial = true;
         }
         
@@ -550,7 +551,7 @@ namespace dtl {
             huge             = false;
             trivial          = false;
             editDistanceOnly = false;
-            fp               = NULL;
+            fp               = nullptr;
         }
         
         /**
