@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -26,10 +26,9 @@
 #include <database/logs.h>
 #include <pugixml/utils.h>
 #include <quill/logic.h>
-using namespace std;
 
 
-void Editor_Html2Format::load (string html)
+void Editor_Html2Format::load (std::string html)
 {
   // The web editor may insert non-breaking spaces. Convert them to normal spaces.
   html = filter::strings::replace (filter::strings::unicode_non_breaking_space_entity (), " ", html);
@@ -38,12 +37,12 @@ void Editor_Html2Format::load (string html)
   // but the pugixml XML parser needs <hr/> and similar elements.
   html = filter::strings::html2xml (html);
   
-  string xml = "<body>" + html + "</body>";
+  std::string xml = "<body>" + html + "</body>";
   // Parse document such that all whitespace is put in the DOM tree.
   // See http://pugixml.org/docs/manual.html for more information.
   // It is not enough to only parse with parse_ws_pcdata_single, it really needs parse_ws_pcdata.
   // This is significant for, for example, the space after verse numbers, among other cases.
-  xml_parse_result result = document.load_string (xml.c_str(), parse_ws_pcdata);
+  pugi::xml_parse_result result = document.load_string (xml.c_str(), pugi::parse_ws_pcdata);
   // Log parsing errors.
   pugixml_utils_error_logger (&result, xml);
 }
@@ -60,49 +59,49 @@ void Editor_Html2Format::run ()
 void Editor_Html2Format::process ()
 {
   // Iterate over the children to retrieve the "p" elements, then process them.
-  xml_node body = document.first_child ();
-  for (xml_node node : body.children()) {
+  pugi::xml_node body = document.first_child ();
+  for (pugi::xml_node node : body.children()) {
     // Process the node.
     processNode (node);
   }
 }
 
 
-void Editor_Html2Format::processNode (xml_node node)
+void Editor_Html2Format::processNode (pugi::xml_node node)
 {
   switch (node.type ()) {
-    case node_element:
+    case pugi::node_element:
     {
       // Skip a note with class "ql-cursor" because that is an internal Quill node.
       // The user didn't insert it.
-      string classs = node.attribute("class").value();
-      if (classs == "ql-cursor") break;
+      std::string classs = node.attribute("class").value();
+      if (classs == quill_caret_class) break;
       // Process node normally.
       openElementNode (node);
-      for (xml_node child : node.children()) {
+      for (pugi::xml_node child : node.children()) {
         processNode (child);
       }
       closeElementNode (node);
       break;
     }
-    case node_pcdata:
+    case pugi::node_pcdata:
     {
       // Add the text with the current character format to the containers.
-      string text = node.text ().get ();
+      std::string text = node.text ().get ();
       texts.push_back(text);
       formats.push_back(current_character_format);
       break;
     }
-    case node_null:
-    case node_document:
-    case node_cdata:
-    case node_comment:
-    case node_pi:
-    case node_declaration:
-    case node_doctype:
+    case pugi::node_null:
+    case pugi::node_document:
+    case pugi::node_cdata:
+    case pugi::node_comment:
+    case pugi::node_pi:
+    case pugi::node_declaration:
+    case pugi::node_doctype:
     default:
     {
-      string nodename = node.name ();
+      std::string nodename = node.name ();
       Database_Logs::log ("XML node " + nodename + " not handled while saving editor text");
       break;
     }
@@ -110,11 +109,11 @@ void Editor_Html2Format::processNode (xml_node node)
 }
 
 
-void Editor_Html2Format::openElementNode (xml_node node)
+void Editor_Html2Format::openElementNode (pugi::xml_node node)
 {
   // The tag and class names of this element node.
-  string tagName = node.name ();
-  string className = update_quill_class (node.attribute ("class").value ());
+  std::string tagName = node.name ();
+  std::string className = update_quill_class (node.attribute ("class").value ());
   
   if (tagName == "p")
   {
@@ -134,11 +133,11 @@ void Editor_Html2Format::openElementNode (xml_node node)
 }
 
 
-void Editor_Html2Format::closeElementNode (xml_node node)
+void Editor_Html2Format::closeElementNode (pugi::xml_node node)
 {
   // The tag and class names of this element node.
-  string tagName = node.name ();
-  string className = update_quill_class (node.attribute ("class").value ());
+  std::string tagName = node.name ();
+  std::string className = update_quill_class (node.attribute ("class").value ());
 
   if (tagName == "p")
   {
@@ -157,7 +156,7 @@ void Editor_Html2Format::closeElementNode (xml_node node)
 }
 
 
-void Editor_Html2Format::openInline (string className)
+void Editor_Html2Format::openInline (std::string className)
 {
   current_character_format = className;
 }
@@ -175,9 +174,9 @@ void Editor_Html2Format::postprocess ()
 }
 
 
-string Editor_Html2Format::update_quill_class (string classname)
+std::string Editor_Html2Format::update_quill_class (std::string classname)
 {
-  classname = filter::strings::replace (quill_logic_class_prefix_block (), "", classname);
-  classname = filter::strings::replace (quill_logic_class_prefix_inline (), "", classname);
+  classname = filter::strings::replace (quill_class_prefix_block, std::string(), classname);
+  classname = filter::strings::replace (quill_class_prefix_inline, std::string(), classname);
   return classname;
 }
