@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2024 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ class Editor_Usfm2Html
 {
 public:
   void load (std::string usfm);
-  void stylesheet (std::string stylesheet);
+  void stylesheet (const std::string& stylesheet);
   void run ();
   std::string get ();
   size_t m_text_tength {0};
@@ -47,16 +47,18 @@ public:
   std::string m_current_paragraph_content {};
   void set_preview ();
 private:
-  std::vector <std::string> m_markers_and_text {}; // Strings alternating between USFM and text.
+  // Strings alternating between USFM and text.
+  std::vector <std::string> m_markers_and_text {};
   unsigned int m_markers_and_text_pointer {0};
   
   // All the style information.
-  std::map <std::string, Database_Styles_Item> m_styles {};
+  std::map <std::string, database::styles1::Item> m_styles {};
   
   // XML nodes.
   pugi::xml_document m_document {};
   pugi::xml_node m_body_node {};
   pugi::xml_node m_notes_node {};
+  pugi::xml_node m_word_level_attributes_node {};
   
   // Standard content markers for notes.
   std::string m_standard_content_marker_foot_end_note {};
@@ -85,17 +87,22 @@ private:
   
   void preprocess ();
   void process ();
-  void postprocess ();
-  void output_as_is (std::string marker, bool is_opening_marker);
+  void output_as_is (const std::string& marker, const bool is_opening_marker);
   void new_paragraph (std::string style = std::string());
   void close_paragraph ();
-  void open_text_style (Database_Styles_Item & style, bool embed);
-  void close_text_style (bool embed);
-  void add_text (std::string text);
-  void add_note (std::string citation, std::string style, bool endnote = false);
-  void add_note_text (std::string text);
+  void open_text_style (const database::styles1::Item& style, const bool embed);
+  void close_text_style (const bool embed);
+  void add_text (const std::string& text);
+  void add_note (const std::string& citation, const std::string& style);
+  void add_note_text (const std::string& text);
   void close_current_note ();
-  void add_notel_link (pugi::xml_node domNode, int identifier, std::string style, std::string text);
-  
+  void add_notel_link (pugi::xml_node& dom_node, const int identifier, const std::string& style, const std::string& text);
   bool road_is_clear ();
+  
+  // Word-level attributes.
+  int m_word_level_attributes_id {0};
+  int get_word_level_attributes_id(const bool next);
+  std::optional<std::string> m_pending_word_level_attributes{};
+  void extract_word_level_attributes();
+  void add_word_level_attributes(const std::string id);
 };
