@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,4 +21,4 @@
 
 #include <config/libraries.h>
 
-void images_logic_import_images (string path);
+void images_logic_import_images (std::string path);
