@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,16 +17,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_LOCALE_TRANSLATE_H
-#define INCLUDED_LOCALE_TRANSLATE_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-extern vector <string> locale_translate_obfuscation_search;
-extern vector <string> locale_translate_obfuscation_replace;
-string translate (string english);
-
-
-#endif
+extern std::vector <std::string> locale_translate_obfuscation_search;
+extern std::vector <std::string> locale_translate_obfuscation_replace;
+std::string translate (std::string english);
