@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -33,42 +33,40 @@
 #include <ipc/focus.h>
 #include <navigation/passage.h>
 #include <notes/actions.h>
-using namespace std;
 
 
-string notes_assign_n_url ()
+std::string notes_assign_n_url ()
 {
   return "notes/assign-n";
 }
 
 
-bool notes_assign_n_acl (void * webserver_request)
+bool notes_assign_n_acl (Webserver_Request& webserver_request)
 {
   return Filter_Roles::access_control (webserver_request, Filter_Roles::manager ());
 }
 
 
-string notes_assign_n (void * webserver_request)
+std::string notes_assign_n (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Notes database_notes (webserver_request);
   Database_NoteAssignment database_noteassignment;
 
   
-  string page;
-  Assets_Header header = Assets_Header (translate("Assign notes"), request);
+  std::string page{};
+  Assets_Header header = Assets_Header (translate("Assign notes"), webserver_request);
   page += header.run ();
   Assets_View view;
 
   
-  string user = request->session_logic ()->currentUser ();
+  const std::string& user = webserver_request.session_logic ()->get_username ();
  
   
   // Notes can be assigned to the assignees.
-  stringstream userblock;
-  vector <string> assignees = database_noteassignment.assignees (user);
-  for (auto & assignee : assignees) {
-    userblock << "<li><a href=" << quoted ("bulk?assign=" + assignee) << ">" << assignee << "</a></li>" << endl;
+  std::stringstream userblock{};
+  const std::vector <std::string> assignees = database_noteassignment.assignees (user);
+  for (const auto& assignee : assignees) {
+    userblock << "<li><a href=" << std::quoted ("bulk?assign=" + assignee) << ">" << assignee << "</a></li>" << std::endl;
   }
   view.set_variable ("userblock", userblock.str());
   
