@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,18 +18,3 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 
 #include <quill/logic.h>
-using namespace std;
-
-
-// The prefix configured in a Quill-based editor for block text.
-string quill_logic_class_prefix_block ()
-{
-  return "b-";
-}
-
-
-// The prefix configured in a Quill-based editor for inline text.
-string quill_logic_class_prefix_inline ()
-{
-  return "i-";
-}
