@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@
 
 #include <config/libraries.h>
 
-string rss_feed_url ();
-bool rss_feed_acl (void * webserver_request);
-string rss_feed (void * webserver_request);
+class Webserver_Request;
+
+std::string rss_feed_url ();
+bool rss_feed_acl (Webserver_Request& webserver_request);
+std::string rss_feed (Webserver_Request& webserver_request);
