@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -30,37 +30,35 @@
 #include <locale/translate.h>
 #include <webserver/request.h>
 #include <sync/logic.h>
-using namespace std;
 
 
-string sync_settings_url ()
+std::string sync_settings_url ()
 {
   return "sync/settings";
 }
 
 
-string sync_settings (void * webserver_request)
+std::string sync_settings (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  Sync_Logic sync_logic = Sync_Logic (webserver_request);
+  Sync_Logic sync_logic (webserver_request);
 
   if (!sync_logic.security_okay ()) {
     // When the Cloud enforces https, inform the client to upgrade.
-    request->response_code = 426;
-    return "";
+    webserver_request.response_code = 426;
+    return std::string();
   }
 
   // Check on the credentials.
-  if (!sync_logic.credentials_okay ()) return "";
+  if (!sync_logic.credentials_okay ()) return std::string();
   
   // Client makes a prioritized server call: Record the client's IP address.
   sync_logic.prioritized_ip_address_record ();
 
   // Get the relevant parameters the client POSTed to us, the server.
-  int action = filter::strings::convert_to_int (request->post ["a"]);
-  string value = request->post ["v"];
+  int action = filter::strings::convert_to_int (webserver_request.post ["a"]);
+  std::string value = webserver_request.post ["v"];
   // The value can be all Bibles, or one Bible.
-  string bible_s = request->post ["b"];
+  std::string bible_s = webserver_request.post ["b"];
 
   switch (action) {
     case Sync_Logic::settings_get_total_checksum:
@@ -69,40 +67,40 @@ string sync_settings (void * webserver_request)
     }
     case Sync_Logic::settings_send_workspace_urls:
     {
-      request->database_config_user()->setWorkspaceURLs (value);
-      return string();
+      webserver_request.database_config_user()->setWorkspaceURLs (value);
+      return std::string();
     }
     case Sync_Logic::settings_get_workspace_urls:
     {
-      return request->database_config_user()->getWorkspaceURLs ();
+      return webserver_request.database_config_user()->getWorkspaceURLs ();
     }
     case Sync_Logic::settings_send_workspace_widths:
     {
-      request->database_config_user()->setWorkspaceWidths (value);
-      return string();
+      webserver_request.database_config_user()->setWorkspaceWidths (value);
+      return std::string();
     }
     case Sync_Logic::settings_get_workspace_widths:
     {
-      return request->database_config_user()->getWorkspaceWidths ();
+      return webserver_request.database_config_user()->getWorkspaceWidths ();
     }
     case Sync_Logic::settings_send_workspace_heights:
     {
-      request->database_config_user()->setWorkspaceHeights (value);
-      return string();
+      webserver_request.database_config_user()->setWorkspaceHeights (value);
+      return std::string();
     }
     case Sync_Logic::settings_get_workspace_heights:
     {
-      return request->database_config_user()->getWorkspaceHeights ();
+      return webserver_request.database_config_user()->getWorkspaceHeights ();
     }
     case Sync_Logic::settings_send_resources_organization:
     {
-      vector <string> resources = filter::strings::explode (value, '\n');
-      request->database_config_user()->setActiveResources (resources);
-      return string();
+      std::vector <std::string> resources = filter::strings::explode (value, '\n');
+      webserver_request.database_config_user()->setActiveResources (resources);
+      return std::string();
     }
     case Sync_Logic::settings_get_resources_organization:
     {
-      vector <string> resources = request->database_config_user()->getActiveResources ();
+      std::vector <std::string> resources = webserver_request.database_config_user()->getActiveResources ();
       return filter::strings::implode (resources, "\n");
     }
     case Sync_Logic::settings_get_bible_id:
@@ -112,16 +110,16 @@ string sync_settings (void * webserver_request)
     }
     case Sync_Logic::settings_get_bible_font:
     {
-      return Database_Config_Bible::getTextFont (bible_s);
+      return database::config::bible::get_text_font (bible_s);
     }
     case Sync_Logic::settings_send_platform:
     {
       // No longer in use, just discard this.
-      return string();
+      return std::string();
     }
     case Sync_Logic::settings_get_privilege_delete_consultation_notes:
     {
-      return filter::strings::convert_to_string (request->database_config_user()->getPrivilegeDeleteConsultationNotes ());
+      return filter::strings::convert_to_string (webserver_request.database_config_user()->getPrivilegeDeleteConsultationNotes ());
     }
     default:
     {
@@ -130,7 +128,7 @@ string sync_settings (void * webserver_request)
 
   // Bad request.
   // Delay a while to obstruct a flood of bad requests.
-  this_thread::sleep_for (chrono::seconds (1));
-  request->response_code = 400;
-  return "";
+  std::this_thread::sleep_for (std::chrono::seconds (1));
+  webserver_request.response_code = 400;
+  return std::string();
 }
