@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -25,7 +25,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <database/users.h>
 #include <database/styles.h>
 #include <database/bibles.h>
-#include <database/check.h>
 #include <database/ipc.h>
 
 class Webserver_Request
@@ -33,60 +32,59 @@ class Webserver_Request
 public:
   Webserver_Request ();
   ~Webserver_Request ();
+  Webserver_Request(const Webserver_Request&) = delete;
+  Webserver_Request operator=(const Webserver_Request&) = delete;
   // Whether the connection runs via the secure server.
-  bool secure;
+  bool secure {false};
   // The session identifier of the cookie sent by the browser.
-  string session_identifier;
+  std::string session_identifier {};
    // Whether to resend the cookie to the browser.
-  bool resend_cookie;
+  bool resend_cookie {false};
    // The browser's or client's remote IPv4 or IPv6 address.
-  string remote_address;
+  std::string remote_address {};
   // The page the browser requests via GET or via POST.
-  string get;
+  std::string get {};
    // Whether it is a POST request.
-  bool is_post;
+  bool is_post {false};
    // The query from the browser, e.g. foo=bar&baz=qux, neatly arranged into a map.
-  map <string, string> query;
+  std::map <std::string, std::string> query {};
    // The browser's user agent, e.g. Mozilla/x.0 (X11; Linux) ...
-  string user_agent;
+  std::string user_agent {};
    // The browser's or client's Accept-Language header.
-  string accept_language;
+  std::string accept_language {};
    // The server's host as requested by the client.
-  string host;
+  std::string host {};
    // The content type of the browser request.
-  string content_type;
+  std::string content_type {};
    // The content length of the browser request.
-  int content_length;
+  int content_length {0};
    // The raw POST data from the browser, item by item.
-  map <string, string> post;
+  std::map <std::string, std::string> post {};
+  // If the POSTed data contains multiple identical keys, store the extra keys here.
+  // Ideally the above container, "post" should be redesigned to be able to contain multiple identical keys.
+  std::map <std::string, std::vector<std::string>> post_multiple{};
    // Header as received from the browser.
-  string if_none_match;
+  std::string if_none_match {};
    // Extra header to be sent back to the browser.
-  string header;
+  std::string header {};
    // Body to be sent back to the browser.
-  string reply;
+  std::string reply {};
    // Response code to be sent to the browser.
-  int response_code;
+  int response_code {0};
    // The requested file's size for browser caching.
-  string etag;
+  std::string etag {};
    // The content type of the response.
-  string response_content_type;
+  std::string response_content_type {};
    // The path of the file to copy from disk straight to the network without loading it in memory.
-  string stream_file;
+  std::string stream_file {};
   // Extra objects.
   Session_Logic * session_logic ();
   Database_Config_User * database_config_user ();
   Database_Users * database_users ();
-  Database_Styles * database_styles ();
-  Database_Bibles * database_bibles ();
-  Database_Check * database_check ();
   Database_Ipc * database_ipc ();
 private:
-  Session_Logic * session_logic_instance = NULL;
-  Database_Config_User * database_config_user_instance = NULL;
-  Database_Users * database_users_instance = NULL;
-  Database_Styles * database_styles_instance = NULL;
-  Database_Bibles * database_bibles_instance = NULL;
-  Database_Check * database_check_instance = NULL;
-  Database_Ipc * database_ipc_instance = NULL;
+  Session_Logic * session_logic_instance { nullptr };
+  Database_Config_User * database_config_user_instance { nullptr };
+  Database_Users * database_users_instance { nullptr };
+  Database_Ipc * database_ipc_instance { nullptr };
 };
